==> jc-1.4.0.tar.gz: soot/jimple/spark/sets/BDDPointsToSet.h <==
// public class soot.jimple.spark.sets.BDDPointsToSet

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 75508657eb5ad9c5 soot_jimple_spark_sets_BDDPointsToSet

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_jimple_spark_sets_BDDPointsToSet_H_
#define _JC_soot_jimple_spark_sets_BDDPointsToSet_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_util_Set$object;
struct _jc_soot_PointsToSet$object;
struct _jc_soot_relations_Relation$object;

// Typedefs
typedef struct _jc_soot_jimple_spark_sets_BDDPointsToSet$sub_refs	_jc_soot_jimple_spark_sets_BDDPointsToSet$sub_refs;
typedef struct _jc_soot_jimple_spark_sets_BDDPointsToSet$sub_nonrefs	_jc_soot_jimple_spark_sets_BDDPointsToSet$sub_nonrefs;
typedef struct _jc_soot_jimple_spark_sets_BDDPointsToSet$refs	_jc_soot_jimple_spark_sets_BDDPointsToSet$refs;
typedef struct _jc_soot_jimple_spark_sets_BDDPointsToSet$nonrefs	_jc_soot_jimple_spark_sets_BDDPointsToSet$nonrefs;
typedef struct _jc_soot_jimple_spark_sets_BDDPointsToSet$object	_jc_soot_jimple_spark_sets_BDDPointsToSet$object;

typedef const struct _jc_soot_jimple_spark_sets_BDDPointsToSet$vmethods	_jc_soot_jimple_spark_sets_BDDPointsToSet$vmethods;
typedef const struct _jc_soot_jimple_spark_sets_BDDPointsToSet$vtable	_jc_soot_jimple_spark_sets_BDDPointsToSet$vtable;
typedef const struct _jc_soot_jimple_spark_sets_BDDPointsToSet$vtype	_jc_soot_jimple_spark_sets_BDDPointsToSet$vtype;

// Constructors
extern void _jc_soot_jimple_spark_sets_BDDPointsToSet$method$_init$634067d225e96d72(_jc_env *, struct _jc_soot_jimple_spark_sets_BDDPointsToSet$object *, struct _jc_soot_relations_Relation$object *);

// Virtual methods
extern jboolean _jc_soot_jimple_spark_sets_BDDPointsToSet$method$hasNonEmptyIntersection$15a39246543071be(_jc_env *, struct _jc_soot_jimple_spark_sets_BDDPointsToSet$object *, struct _jc_object *);
extern jboolean _jc_soot_jimple_spark_sets_BDDPointsToSet$method$isEmpty$551bea84f4e0f0cb(_jc_env *, struct _jc_soot_jimple_spark_sets_BDDPointsToSet$object *);
extern struct _jc_object *_jc_soot_jimple_spark_sets_BDDPointsToSet$method$possibleClassConstants$6e3226531d53717d(_jc_env *, struct _jc_soot_jimple_spark_sets_BDDPointsToSet$object *);
extern struct _jc_object *_jc_soot_jimple_spark_sets_BDDPointsToSet$method$possibleStringConstants$f7b905484b329d7f(_jc_env *, struct _jc_soot_jimple_spark_sets_BDDPointsToSet$object *);
extern struct _jc_object *_jc_soot_jimple_spark_sets_BDDPointsToSet$method$possibleTypes$bdfe38321205065e(_jc_env *, struct _jc_soot_jimple_spark_sets_BDDPointsToSet$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_spark_sets_BDDPointsToSet$method_info$hasNonEmptyIntersection$15a39246543071be;
extern _jc_method _jc_soot_jimple_spark_sets_BDDPointsToSet$method_info$isEmpty$551bea84f4e0f0cb;
extern _jc_method _jc_soot_jimple_spark_sets_BDDPointsToSet$method_info$possibleClassConstants$6e3226531d53717d;
extern _jc_method _jc_soot_jimple_spark_sets_BDDPointsToSet$method_info$possibleStringConstants$f7b905484b329d7f;
extern _jc_method _jc_soot_jimple_spark_sets_BDDPointsToSet$method_info$possibleTypes$bdfe38321205065e;

// Virtual methods structure
struct _jc_soot_jimple_spark_sets_BDDPointsToSet$vmethods {
	jboolean	(*hasNonEmptyIntersection$15a39246543071be)(_jc_env *, struct _jc_soot_jimple_spark_sets_BDDPointsToSet$object *, struct _jc_object *);
	jboolean	(*isEmpty$551bea84f4e0f0cb)(_jc_env *, struct _jc_soot_jimple_spark_sets_BDDPointsToSet$object *);
	struct _jc_object	*(*possibleClassConstants$6e3226531d53717d)(_jc_env *, struct _jc_soot_jimple_spark_sets_BDDPointsToSet$object *);
	struct _jc_object	*(*possibleStringConstants$f7b905484b329d7f)(_jc_env *, struct _jc_soot_jimple_spark_sets_BDDPointsToSet$object *);
	struct _jc_object	*(*possibleTypes$bdfe38321205065e)(_jc_env *, struct _jc_soot_jimple_spark_sets_BDDPointsToSet$object *);
};

// Vtable
struct _jc_soot_jimple_spark_sets_BDDPointsToSet$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_spark_sets_BDDPointsToSet$vmethods	soot_jimple_spark_sets_BDDPointsToSet;
};

// Vtype
struct _jc_soot_jimple_spark_sets_BDDPointsToSet$vtype {
	_jc_type			type;
	_jc_soot_jimple_spark_sets_BDDPointsToSet$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_spark_sets_BDDPointsToSet$sub_refs {
	struct _jc_soot_relations_Relation$object	*bdd;
};

// Reference instance fields (object)
struct _jc_soot_jimple_spark_sets_BDDPointsToSet$refs {
    _jc_soot_jimple_spark_sets_BDDPointsToSet$sub_refs	soot_jimple_spark_sets_BDDPointsToSet;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_spark_sets_BDDPointsToSet$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_spark_sets_BDDPointsToSet$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_spark_sets_BDDPointsToSet$sub_nonrefs	soot_jimple_spark_sets_BDDPointsToSet;
};

// Object instance structure
struct _jc_soot_jimple_spark_sets_BDDPointsToSet$object {
	_jc_soot_jimple_spark_sets_BDDPointsToSet$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_spark_sets_BDDPointsToSet$vtype	*vtype;
	_jc_soot_jimple_spark_sets_BDDPointsToSet$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_spark_sets_BDDPointsToSet$vtype _jc_soot_jimple_spark_sets_BDDPointsToSet$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_spark_sets_BDDPointsToSet, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_spark_sets_BDDPointsToSet$class_object;

#endif	/* _JC_soot_jimple_spark_sets_BDDPointsToSet_H_ */

==> jc-1.4.6.tar.gz: soot/jimple/spark/sets/BDDPointsToSet.h <==
// public class soot.jimple.spark.sets.BDDPointsToSet

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 75508657eb5ad9c5 soot_jimple_spark_sets_BDDPointsToSet

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_jimple_spark_sets_BDDPointsToSet_H_
#define _JC_soot_jimple_spark_sets_BDDPointsToSet_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_util_Set$object;
struct _jc_soot_PointsToSet$object;
struct _jc_soot_relations_Relation$object;

// Typedefs
typedef struct _jc_soot_jimple_spark_sets_BDDPointsToSet$sub_refs	_jc_soot_jimple_spark_sets_BDDPointsToSet$sub_refs;
typedef struct _jc_soot_jimple_spark_sets_BDDPointsToSet$sub_nonrefs	_jc_soot_jimple_spark_sets_BDDPointsToSet$sub_nonrefs;
typedef struct _jc_soot_jimple_spark_sets_BDDPointsToSet$refs	_jc_soot_jimple_spark_sets_BDDPointsToSet$refs;
typedef struct _jc_soot_jimple_spark_sets_BDDPointsToSet$nonrefs	_jc_soot_jimple_spark_sets_BDDPointsToSet$nonrefs;
typedef struct _jc_soot_jimple_spark_sets_BDDPointsToSet$object	_jc_soot_jimple_spark_sets_BDDPointsToSet$object;

typedef const struct _jc_soot_jimple_spark_sets_BDDPointsToSet$vmethods	_jc_soot_jimple_spark_sets_BDDPointsToSet$vmethods;
typedef const struct _jc_soot_jimple_spark_sets_BDDPointsToSet$vtable	_jc_soot_jimple_spark_sets_BDDPointsToSet$vtable;
typedef const struct _jc_soot_jimple_spark_sets_BDDPointsToSet$vtype	_jc_soot_jimple_spark_sets_BDDPointsToSet$vtype;

// Constructors
extern void _jc_soot_jimple_spark_sets_BDDPointsToSet$method$_init$634067d225e96d72(_jc_env *, struct _jc_soot_jimple_spark_sets_BDDPointsToSet$object *, struct _jc_soot_relations_Relation$object *) _JC_JCNI_ATTR;

// Virtual methods
extern jboolean _jc_soot_jimple_spark_sets_BDDPointsToSet$method$hasNonEmptyIntersection$15a39246543071be(_jc_env *, struct _jc_soot_jimple_spark_sets_BDDPointsToSet$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern jboolean _jc_soot_jimple_spark_sets_BDDPointsToSet$method$isEmpty$551bea84f4e0f0cb(_jc_env *, struct _jc_soot_jimple_spark_sets_BDDPointsToSet$object *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_soot_jimple_spark_sets_BDDPointsToSet$method$possibleClassConstants$6e3226531d53717d(_jc_env *, struct _jc_soot_jimple_spark_sets_BDDPointsToSet$object *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_soot_jimple_spark_sets_BDDPointsToSet$method$possibleStringConstants$f7b905484b329d7f(_jc_env *, struct _jc_soot_jimple_spark_sets_BDDPointsToSet$object *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_soot_jimple_spark_sets_BDDPointsToSet$method$possibleTypes$bdfe38321205065e(_jc_env *, struct _jc_soot_jimple_spark_sets_BDDPointsToSet$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_spark_sets_BDDPointsToSet$method_info$hasNonEmptyIntersection$15a39246543071be;
extern _jc_method _jc_soot_jimple_spark_sets_BDDPointsToSet$method_info$isEmpty$551bea84f4e0f0cb;
extern _jc_method _jc_soot_jimple_spark_sets_BDDPointsToSet$method_info$possibleClassConstants$6e3226531d53717d;
extern _jc_method _jc_soot_jimple_spark_sets_BDDPointsToSet$method_info$possibleStringConstants$f7b905484b329d7f;
extern _jc_method _jc_soot_jimple_spark_sets_BDDPointsToSet$method_info$possibleTypes$bdfe38321205065e;

// Virtual methods structure
struct _jc_soot_jimple_spark_sets_BDDPointsToSet$vmethods {
	jboolean	(*hasNonEmptyIntersection$15a39246543071be)(_jc_env *, struct _jc_soot_jimple_spark_sets_BDDPointsToSet$object *, struct _jc_object *) _JC_JCNI_ATTR;
	jboolean	(*isEmpty$551bea84f4e0f0cb)(_jc_env *, struct _jc_soot_jimple_spark_sets_BDDPointsToSet$object *) _JC_JCNI_ATTR;
	struct _jc_object	*(*possibleClassConstants$6e3226531d53717d)(_jc_env *, struct _jc_soot_jimple_spark_sets_BDDPointsToSet$object *) _JC_JCNI_ATTR;
	struct _jc_object	*(*possibleStringConstants$f7b905484b329d7f)(_jc_env *, struct _jc_soot_jimple_spark_sets_BDDPointsToSet$object *) _JC_JCNI_ATTR;
	struct _jc_object	*(*possibleTypes$bdfe38321205065e)(_jc_env *, struct _jc_soot_jimple_spark_sets_BDDPointsToSet$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_jimple_spark_sets_BDDPointsToSet$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_spark_sets_BDDPointsToSet$vmethods	soot_jimple_spark_sets_BDDPointsToSet;
};

// Vtype
struct _jc_soot_jimple_spark_sets_BDDPointsToSet$vtype {
	_jc_type			type;
	_jc_soot_jimple_spark_sets_BDDPointsToSet$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_spark_sets_BDDPointsToSet$sub_refs {
	struct _jc_soot_relations_Relation$object	*bdd;
};

// Reference instance fields (object)
struct _jc_soot_jimple_spark_sets_BDDPointsToSet$refs {
    _jc_soot_jimple_spark_sets_BDDPointsToSet$sub_refs	soot_jimple_spark_sets_BDDPointsToSet;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_spark_sets_BDDPointsToSet$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_spark_sets_BDDPointsToSet$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_spark_sets_BDDPointsToSet$sub_nonrefs	soot_jimple_spark_sets_BDDPointsToSet;
};

// Object instance structure
struct _jc_soot_jimple_spark_sets_BDDPointsToSet$object {
	_jc_soot_jimple_spark_sets_BDDPointsToSet$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_spark_sets_BDDPointsToSet$vtype	*vtype;
	_jc_soot_jimple_spark_sets_BDDPointsToSet$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_spark_sets_BDDPointsToSet$vtype _jc_soot_jimple_spark_sets_BDDPointsToSet$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_spark_sets_BDDPointsToSet, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_spark_sets_BDDPointsToSet$class_object;

#endif	/* _JC_soot_jimple_spark_sets_BDDPointsToSet_H_ */
